@@ -1,5 +1,5 @@
+from bt import backend_to_check, gnome, kde
 from pyscreenshot.util import py2
-from ref import backend_to_check, gnome, kde
 
 # no jeepney for py2
 if kde() and not py2():
