@@ -1,5 +1,5 @@
+from bt import backend_to_check, check_import
 from pyscreenshot.util import py2
-from ref import backend_to_check, check_import
 
 # no pygtk for py3
 if py2() and check_import("gtk"):
